@@ -20,6 +20,7 @@
 
 #include "config.h"
 
+#include "bolt-dbus.h"
 #include "bolt-device.h"
 #include "bolt-domain.h"
 #include "bolt-error.h"
@@ -28,8 +29,6 @@
 
 #include "bolt-log.h"
 
-#include "bolt-daemon-resource.h"
-
 #include <glib.h>
 #include <gio/gio.h>
 #include <glib/gprintf.h>
@@ -389,7 +388,7 @@ main (int argc, char **argv)
 
   g_test_init (&argc, &argv, NULL);
 
-  g_resources_register (bolt_daemon_get_resource ());
+  bolt_dbus_ensure_resources ();
 
   g_test_add ("/logging/basic",
               TestLog,
